@@ -1,6 +1,6 @@
-from publishers import publisher
-from subscribers import subscriber
-from constants import *
+from .publishers import publisher
+from .subscribers import subscriber
+from .constants import *
 import time
 import threading
 
@@ -14,7 +14,7 @@ def test_init_subscriber():
     p=publisher('ipc:///tmp/test/0')
     def foo(topic, message):
         pass
-    s=subscriber('ipc:///tmp/test/0',[''],foo,JSON)
+    s=subscriber('ipc:///tmp/test/0',[u''],foo,JSON)
     assert p is not None
     assert p.sock() is not None
     assert s is not None
@@ -28,16 +28,16 @@ def test_init_basic_subscribe():
     p=publisher('ipc:///tmp/test/0')
     def foo(topic, message):
         m.acquire()
-        assert message == 'test message'
+        assert message == u'test message'
         m.notifyAll()
         m.release()
-    s=subscriber('ipc:///tmp/test/0',['test'],foo,STRING)
+    s=subscriber('ipc:///tmp/test/0',[u'test'],foo,STRING)
     s.start()
     assert p is not None
     assert p.sock() is not None
     assert s is not None
     assert s.sock() is not None
-    p.publish('test message',STRING,'test')
+    p.publish(u'test message',STRING,'test')
     m.wait() 
     m.release()
     s.stop()   
